TYPE
  LOGLEVEL : (CRITICAL, WARNING, INFO, DEBUG) := INFO;
END_TYPE

FUNCTION_BLOCK LOGGER
  VAR_INPUT
    TRIG : BOOL;
    MSG : STRING;
    LEVEL : LOGLEVEL := INFO;
  END_VAR
  VAR
    TRIG0 : BOOL;
  END_VAR

  IF TRIG AND NOT TRIG0 THEN
  {{
   LogMessage(GetFbVar(LEVEL),(char*)GetFbVar(MSG, .body),GetFbVar(MSG, .len));
  }}
  END_IF;
  TRIG0:=TRIG;
END_FUNCTION_BLOCK



FUNCTION_BLOCK python_eval
  VAR_INPUT
    TRIG : BOOL;
    CODE : STRING;
  END_VAR
  VAR_OUTPUT
    ACK : BOOL;
    RESULT : STRING;
  END_VAR
  VAR
    STATE : DWORD;
    BUFFER : STRING;
    PREBUFFER : STRING;
    TRIGM1 : BOOL;
    TRIGGED : BOOL;
  END_VAR

  {extern void __PythonEvalFB(int, PYTHON_EVAL*);__PythonEvalFB(0, data__);}
END_FUNCTION_BLOCK

FUNCTION_BLOCK python_poll
  VAR_INPUT
    TRIG : BOOL;
    CODE : STRING;
  END_VAR
  VAR_OUTPUT
    ACK : BOOL;
    RESULT : STRING;
  END_VAR
  VAR
    STATE : DWORD;
    BUFFER : STRING;
    PREBUFFER : STRING;
    TRIGM1 : BOOL;
    TRIGGED : BOOL;
  END_VAR

  {extern void __PythonEvalFB(int, PYTHON_EVAL*);__PythonEvalFB(1,(PYTHON_EVAL*)(void*)data__);}
END_FUNCTION_BLOCK

FUNCTION_BLOCK python_gear
  VAR_INPUT
    N : UINT;
    TRIG : BOOL;
    CODE : STRING;
  END_VAR
  VAR_OUTPUT
    ACK : BOOL;
    RESULT : STRING;
  END_VAR
  VAR
    py_eval : python_eval;
    COUNTER : UINT;
    ADD10_OUT : UINT;
    EQ13_OUT : BOOL;
    SEL15_OUT : UINT;
    AND7_OUT : BOOL;
  END_VAR

  ADD10_OUT := ADD(COUNTER, 1);
  EQ13_OUT := EQ(N, ADD10_OUT);
  SEL15_OUT := SEL(EQ13_OUT, ADD10_OUT, 0);
  COUNTER := SEL15_OUT;
  AND7_OUT := AND(EQ13_OUT, TRIG);
  py_eval(TRIG := AND7_OUT, CODE := CODE);
  ACK := py_eval.ACK;
  RESULT := py_eval.RESULT;
END_FUNCTION_BLOCK


FUNCTION_BLOCK IF_word_bool
  VAR_INPUT
    In0 : WORD;
  END_VAR
  VAR
    Out0 : BOOL := true;
    Out1 : BOOL := false;
    Val0 : BOOL;
    Val_comp : WORD := 32768;
  END_VAR
  VAR_OUTPUT
    Out : BOOL;
  END_VAR

  IF In0 > Val_comp THEN
    Val0 := Out1;
  ELSE
    Val0 := Out0;
  END_IF;

  Out := Val0;
END_FUNCTION_BLOCK

FUNCTION_BLOCK IF_bool_word
  VAR_INPUT
    In0 : BOOL;
  END_VAR
  VAR
    Out0 : WORD := 0;
    Out1 : WORD := 65535;
    Val0 : WORD;
  END_VAR
  VAR_OUTPUT
    Out : WORD;
  END_VAR

  IF In0 THEN
    Val0 := Out1;
  ELSE
    Val0 := Out0;
  END_IF;

  Out := Val0;
END_FUNCTION_BLOCK

FUNCTION_BLOCK IF_word_word
  VAR_INPUT
    In0 : WORD;
  END_VAR
  VAR
    Out0 : WORD := 65535;
    Out1 : WORD := 0;
    Val0 : WORD;
    Val_comp : WORD := 32767;
  END_VAR
  VAR_OUTPUT
    Out : WORD;
  END_VAR

  IF In0 > Val_comp THEN
    Val0 := Out1;
  ELSE
    Val0 := Out0;
  END_IF;

  Out := Val0;
END_FUNCTION_BLOCK

PROGRAM Pi_LED_an_no_pull
  VAR
    out_23 : BOOL := false;
    out_22 : BOOL := false;
    out_25 : BOOL := false;
    out_20 : BOOL := true;
    inp_an0 : UINT;
    inp_an1 : UINT;
    inp_an2 : UINT;
    inp_an3 : UINT;
  END_VAR
  VAR
    TOF3 : TOF;
    TOF4 : TOF;
    TOF5 : TOF;
    LT32_OUT : BOOL;
    GE31_OUT : BOOL;
    AND33_OUT : BOOL;
    LT28_OUT : BOOL;
    GE27_OUT : BOOL;
    AND29_OUT : BOOL;
    LT44_OUT : BOOL;
    GE43_OUT : BOOL;
    AND47_OUT : BOOL;
  END_VAR

  LT32_OUT := LT(inp_an0, 100);
  GE31_OUT := GE(inp_an0, 90);
  AND33_OUT := AND(LT32_OUT, GE31_OUT);
  TOF5(IN := AND33_OUT, PT := T#50ms);
  out_23 := TOF5.Q;
  LT28_OUT := LT(inp_an0, 130);
  GE27_OUT := GE(inp_an0, 120);
  AND29_OUT := AND(LT28_OUT, GE27_OUT);
  TOF4(IN := AND29_OUT, PT := T#50ms);
  out_22 := TOF4.Q;
  LT44_OUT := LT(inp_an0, 85);
  GE43_OUT := GE(inp_an0, 75);
  AND47_OUT := AND(LT44_OUT, GE43_OUT);
  TOF3(IN := AND47_OUT, PT := T#50ms);
  out_25 := TOF3.Q;
END_PROGRAM


CONFIGURATION Config0

  RESOURCE Res0 ON PLC
    TASK task0(INTERVAL := T#20ms,PRIORITY := 1);
    PROGRAM instance0 WITH task0 : Pi_LED_an_no_pull;
  END_RESOURCE
END_CONFIGURATION
